@@ -9,6 +9,7 @@ use App::Cmd::Setup -command;
 use 5.012;
 
 use Cwd;
+use File::Spec;
 use File::Spec::Functions;
 use File::Copy;
 use File::Copy::Recursive qw(dircopy);
@@ -44,6 +45,7 @@ sub execute {
   my $pensource = $opt->{directory};
 
   {
+my $user = $ENV{'USER'};
   my $config_file = <<"EOCF";
 
 #general 'mira' config, you can make config files for any floor in /config/FLOOR_NAME.yml
@@ -52,7 +54,7 @@ sub execute {
 title: Your Site Tilte
 description: Description of your site
 
-author: $ENV{USER}
+author: $user
 email: your-email\@domain.com
 
  # the base hostname & protocol for your site
@@ -79,15 +81,12 @@ archive_post_num: 10
 ## if create new entry without --floor switch, mira use this field
 default_floor: blog
 
-## Mira's main directory in your pc
-penurl: $pensource
-
 
 ## template path by root is penurlPATH/template
 ## if you want use a custom template for examle in penurlPATH/template/CustomThEM
 ## just type custom template folder name
 #> template: Custom_Template_Folde_Name
-template: mira-theme-rtl
+template: default-theme
 
 ## the fields you want use for archive, like category, tag and ...
 ## by default Mira archive date field dont need type it here
@@ -102,13 +101,13 @@ lists:
 
 #url address for long keys or unicode which you want make latin addres for'em
 # for example if you have 'longcategoryname' you can make /category/lcn
-namespace:
-  veryverylongarchivename : vlan
-  آموزش: learn
-  کتاب: book
-  درباره: about
-  شخصی: personal
-  ترمینال: terminal
+#namespace:
+#  veryverylongarchivename : vlan
+#  learnsections: learn
+#  mybooksButWithALongname: book
+#  aboutThisSite: about
+#  myPersonalDailyDiary: personal
+#  terminalCommandLearning: terminal
 
 EOCF
 
@@ -121,6 +120,7 @@ EOCF
 
   make_path catdir($pensource,"content");
   make_path catdir($pensource,"content","blog");
+  make_path catdir($pensource,"config");
 
   my $sharedir = dist_dir('Mira');
 
